This function searches the closest match of a string in a vector of strings using the levenshtein distance, sometimes useful for matching gene names.
Examples
closestMatch("DFNB31", c("DNMT1", "DTNBP1", "IFNB1"))
#> [[1]]
#> [1] "DTNBP1" "IFNB1"
#>
#> [[2]]
#> [1] 2 3
#>
#[[1]] [1] "DTNBP1" "IFNB1"
#[[2]] [1] 2 3