Given a character vector, this function creates an empty list with names corresponding to the elements of the vector.
Examples
createNamedList(c("x", "y"))
#> $x
#> NULL
#>
#> $y
#> NULL
#>
Given a character vector, this function creates an empty list with names corresponding to the elements of the vector.
createNamedList(c("x", "y"))
#> $x
#> NULL
#>
#> $y
#> NULL
#>